@@ -4,6 +4,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 # SPDX-FileCopyrightText: Michael Terry
 
+from dogtail import tree
 from gi.repository import GLib
 
 from . import BaseTest
@@ -20,9 +21,9 @@ class PreferencesTest(BaseTest):
         # Test that there's a special first time welcome screen
         self.app.button("Create My First Backup")
 
-        # Grab switch from main window, set last-backup time so the switch shows up
+        # Grab switch from main window, set last-run time so the switch shows up
         now = GLib.DateTime.new_now_utc().format_iso8601()
-        self.set_string("last-backup", now)
+        self.set_string("last-run", now)
         periodic_main = self.app.window("Backups").child(name="Automatic backup")
 
         prefs = self.app.window("Preferences")
@@ -114,7 +115,7 @@ class PreferencesTest(BaseTest):
             "~/Documents/path",
             "~/Downloads",
             "~/Music/path",
-            "Home ({})".format(homename),
+            "~/Public",
             "~/Templates/path",
             "~/Videos",
             "Home ({})".format(homename),
@@ -138,7 +139,7 @@ class PreferencesTest(BaseTest):
         # Add one
         add = table.child(name="Add")
         add.click()
-        dlg = self.app.child(roleName="file chooser")
+        dlg = tree.root.child(roleName="file chooser", name="Choose folders")
         dlg.child(name="Documents").click()
         dlg.child(name="Add").click()
         self.assertListEqual(self.table_names(table), ["~/Pictures", "~/Documents"])
